@@ -1,7 +1,7 @@
 # From https://www.r-bloggers.com/2019/06/gen-experiments-fitting-a-stability-variance-model-with-r/
 #library(spaMM)
 
-cat(crayon::yellow("\ntest of yield stability analysis:"))
+cat(cli::col_yellow("\ntest of yield stability analysis:"))
 
 if (spaMM.getOption("example_maxtime")>1.5) {
   if (requireNamespace("agridat", quietly = TRUE)) {
@@ -44,5 +44,5 @@ if (spaMM.getOption("example_maxtime")>1.5) {
     
     detach("package:nlme")
     
-  } else cat(crayon::bgGreen("Data 'onofri.winterwheat' not available for testing."))
+  } else cat(cli::bg_green(cli::col_black("Data 'onofri.winterwheat' not available for testing.")))
 }
