@@ -1,4 +1,4 @@
-cat(crayon::yellow("\ntest of Infusion compatibility:"))
+cat(cli::col_yellow("\ntest of Infusion compatibility:"))
 
 if (requireNamespace("Infusion",quietly=TRUE)) {
   Infusion::Infusion.options(spaMM.options("example_maxtime"))
@@ -11,7 +11,7 @@ if (requireNamespace("Infusion",quietly=TRUE)) {
   if (do.call("require",list(package="Rmixmod", quietly = TRUE))) {
     example("example_raw",package="Infusion",ask=FALSE) ## detected calc_logdisp_cov issues 
   } else {
-    cat( crayon::bgGreen("package 'Rmixmod' not available, cannot run Infusion test.\n" ))
+    cat(cli::bg_green(cli::col_black("package 'Rmixmod' not available, cannot run Infusion test.\n" )))
   }
 }
 
