@@ -1,10 +1,10 @@
-cat(crayon::yellow("\ntest DHGLM:"))
+cat(cli::col_yellow("\ntest DHGLM:"))
 
 data("crack") # crack data, LeeNP06 chapter 11 etc
 hlfit <- HLfit(y~crack0+(1|specimen),family=Gamma(log),data=crack, HLmethod="REML", 
                rand.family=inverse.Gamma(log), 
                resid.model=list(formula=~cycle+(1|specimen),fixed=list(phi=NA))   ) 
-# where phi=NA is a way to force estimatation of a scalar phi OF the residual model.
+# where phi=NA is a way to force estimation of a scalar phi OF the residual model.
 #  This replicates what Lee et al. did, but is not spaMM's default.
 
 # testthat::expect_equal(hlfit$APHLs$p_v,789.60762,tolerance=1e-4)
@@ -16,7 +16,7 @@ if (how(hlfit,verbose=FALSE)$obsInfo) {
 set.seed(123)
 simulate(hlfit)
 
-if (FALSE) {  
+if (spaMM.getOption("example_maxtime") > 2) {  # test eg of code for partially fixed ranCoefs.
   hlfit <- HLfit(y~crack0+(1|specimen),family=Gamma(log),data=crack, HLmethod="REML", 
                  rand.family=inverse.Gamma(log), resid.model=list(formula=~cycle+(1|specimen),fixed=list(lambda=0.666))   )
   # and with partially-fixed ranCoefs in the residual dispersion model:
