@@ -1,4 +1,4 @@
-cat(crayon::yellow("\ntest-pdep-effects.R: "))
+cat(cli::col_yellow("\ntest-pdep-effects.R: "))
 
 # Easily goes wrong with factors -> fixes for the following checks in v4.4.4
 
@@ -22,4 +22,4 @@ plot_effects(fit3, "Species")
 iris4 <- iris
 iris4$Species <- as.character(iris4$Species)
 fit4 <- fitme(Petal.Length ~ Sepal.Length + Species, data = iris4)
-plot_effects(fit4, "Species")
\ No newline at end of file
+plot_effects(fit4, "Species")
