@@ -1,4 +1,4 @@
-cat(crayon::yellow("\ntest of random-slope model:"))
+cat(cli::col_yellow("\ntest of random-slope model:"))
 if(requireNamespace("lme4", quietly = TRUE)) {
   data("sleepstudy",package = "lme4")
   (res <- HLfit(Reaction ~ Days + (Days|Subject), data = sleepstudy)) 
@@ -65,4 +65,4 @@ if (FALSE) {
   fitme(Reaction ~ Days + (Days|Subject), data = sleepstudy,
         fixed=list(phi=700,ranCoefs=list("1"=c(600,0.25,30)))) ## FIXME does not work without list()
   spaMM.options(sparse_precision = NULL)
-}
\ No newline at end of file
+}
